

set -ex



rio --help
rio info /opt/concourse/worker/volumes/live/4dec5ffd-831b-41c4-59a2-155adb01a40d/volume/rsync-recipes/rasterio-1.1.0-python_3.7-on-osx/test_data/test.tif
$PYTHON -m pytest -v -m "not wheel" -rxXs -k "not (test_transform_geom_polygon_cutting or test_transform_geom_polygon_offset)" tests
exit 0
